@@ -5,7 +5,7 @@ use std::borrow::Cow;
 pub struct TestCases {
     runner: std::cell::RefCell<crate::RunnerSpec>,
     bins: std::cell::RefCell<crate::BinRegistry>,
-    substitutions: std::cell::RefCell<crate::elide::Substitutions>,
+    substitutions: std::cell::RefCell<snapbox::Redactions>,
     has_run: std::cell::Cell<bool>,
 }
 
@@ -137,18 +137,35 @@ impl TestCases {
         var: &'static str,
         value: impl Into<Cow<'static, str>>,
     ) -> Result<&Self, crate::Error> {
+        let value = value.into();
+        let value = snapbox::filter::normalize_paths(&snapbox::filter::normalize_lines(&value));
         self.substitutions.borrow_mut().insert(var, value)?;
         Ok(self)
     }
 
     /// Batch add variables for normalizing output
     ///
-    /// See `insert_var`.
+    /// See [`TestCases::insert_var`].
     pub fn extend_vars(
         &self,
         vars: impl IntoIterator<Item = (&'static str, impl Into<Cow<'static, str>>)>,
     ) -> Result<&Self, crate::Error> {
-        self.substitutions.borrow_mut().extend(vars)?;
+        self.substitutions
+            .borrow_mut()
+            .extend(vars.into_iter().map(|(var, value)| {
+                let value = value.into();
+                let value =
+                    snapbox::filter::normalize_paths(&snapbox::filter::normalize_lines(&value));
+                (var, value)
+            }))?;
+        Ok(self)
+    }
+
+    /// Remove an existing var values
+    ///
+    /// See [`TestCases::insert_var`].
+    pub fn clear_var(&self, var: &'static str) -> Result<&Self, crate::Error> {
+        self.substitutions.borrow_mut().remove(var)?;
         Ok(self)
     }
 
